summaryrefslogtreecommitdiff
path: root/source3/utils/profiles.c
diff options
context:
space:
mode:
authorMichael Adam <obnox@samba.org>2009-02-24 15:19:18 +0100
committerMichael Adam <obnox@samba.org>2009-02-26 13:22:51 +0100
commit58fc61217db68e553119bc49369362672590c19d (patch)
treec8a50381b24bf15ff04c7c37984654de9fa7ea5d /source3/utils/profiles.c
parentb56f449d6b1cdc527dc553cf0fe774b51a272642 (diff)
downloadsamba-58fc61217db68e553119bc49369362672590c19d.tar.gz
samba-58fc61217db68e553119bc49369362672590c19d.tar.bz2
samba-58fc61217db68e553119bc49369362672590c19d.zip
s3:registry: replace typedef "REGSUBKEY_CTR" by "struct regsubkey_ctr"
This paves the way for hiding the typedef and the implementation from the surface. Michael
Diffstat (limited to 'source3/utils/profiles.c')
-rw-r--r--source3/utils/profiles.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/source3/utils/profiles.c b/source3/utils/profiles.c
index bbbaaf089f..2c9bc36faf 100644
--- a/source3/utils/profiles.c
+++ b/source3/utils/profiles.c
@@ -118,7 +118,7 @@ static bool copy_registry_tree( REGF_FILE *infile, REGF_NK_REC *nk,
REGF_NK_REC *key, *subkey;
SEC_DESC *new_sd;
REGVAL_CTR *values;
- REGSUBKEY_CTR *subkeys;
+ struct regsubkey_ctr *subkeys;
int i;
char *path;
@@ -132,7 +132,7 @@ static bool copy_registry_tree( REGF_FILE *infile, REGF_NK_REC *nk,
verbose_output("ACL for %s%s%s\n", parentpath, parent ? "\\" : "", nk->keyname);
swap_sid_in_acl( new_sd, &old_sid, &new_sid );
- if ( !(subkeys = TALLOC_ZERO_P( NULL, REGSUBKEY_CTR )) ) {
+ if ( !(subkeys = TALLOC_ZERO_P( NULL, struct regsubkey_ctr )) ) {
DEBUG(0,("copy_registry_tree: talloc() failure!\n"));
return False;
}
@@ -150,7 +150,7 @@ static bool copy_registry_tree( REGF_FILE *infile, REGF_NK_REC *nk,
(const char *)nk->values[i].data, (nk->values[i].data_size & ~VK_DATA_IN_OFFSET) );
}
/* copy subkeys into the REGSUBKEY_CTR */
while ( (subkey = regfio_fetch_subkey( infile, nk )) ) {
regsubkey_ctr_addkey( subkeys, subkey->keyname );
@@ -150,7 +150,7 @@ static bool copy_registry_tree( REGF_FILE *infile, REGF_NK_REC *nk,
(const char *)nk->values[i].data, (nk->values[i].data_size & ~VK_DATA_IN_OFFSET) );
}
- /* copy subkeys into the REGSUBKEY_CTR */
+ /* copy subkeys into the struct regsubkey_ctr */
while ( (subkey = regfio_fetch_subkey( infile, nk )) ) {
regsubkey_ctr_addkey( subkeys, subkey->keyname );